=================
openflowthrough
=================


.. image:: https://img.shields.io/pypi/v/openflowthrough.svg
        :target: https://pypi.python.org/pypi/openflowthrough

.. image:: https://readthedocs.org/projects/openflowthrough/badge/?version=latest
        :target: https://openflowthrough.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

Software for controlling the Open Flow-through sampling device.

Installation
------------

Install via pip:

$ pip install openflowthrough [--upgrade]

Documentation
-------------

Full documentation can be found here.

Dependencies for Local Development
----------------------------------

If you wish to build the local documentation or run unit tests, there are a few additional dependencies. Those can be installed by:

pip install -e ".[docs, tests, develop]"

License
-------

This library is licensed under the MIT license. The full text of the license can be found in this repository at LICENSE.txt.